aboutsummaryrefslogtreecommitdiffstats
path: root/wsutil/filesystem.c
diff options
context:
space:
mode:
authorJoão Valverde <joao.valverde@tecnico.ulisboa.pt>2018-12-04 01:46:01 +0000
committerJoão Valverde <j@v6e.pt>2018-12-04 21:01:46 +0000
commit6a8168169aa6002e72d7bcfe4f9cf692ce632239 (patch)
tree55f3c3de3caa97c52ce22914e5ab266048a3f772 /wsutil/filesystem.c
parent011ca1ed9b58c458a0b5d664b12ecbf439057280 (diff)
wsutil: Rename DATAFILE_DIR variable
Rename DATAFILE_DIR to be closer to CMake and avoid mixing with the staging dir path variable of the same name. Change-Id: I7b1e02152d8bde14cca210fbfae4acbdba7d78d7 Reviewed-on: https://code.wireshark.org/review/30916 Petri-Dish: João Valverde <j@v6e.pt> Tested-by: Petri Dish Buildbot Reviewed-by: João Valverde <j@v6e.pt>
Diffstat (limited to 'wsutil/filesystem.c')
-rw-r--r--wsutil/filesystem.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/wsutil/filesystem.c b/wsutil/filesystem.c
index 5a2a16032d..ffb7fed70b 100644
--- a/wsutil/filesystem.c
+++ b/wsutil/filesystem.c
@@ -586,7 +586,7 @@ init_progfile_dir(const char *arg0
if (getcwd(curdir, path_max) == NULL) {
/*
* It failed - give up, and just stick
- * with DATAFILE_DIR.
+ * with DATA_DIR.
*/
g_free(curdir);
return g_strdup_printf("getcwd failed: %s\n",
@@ -771,7 +771,7 @@ get_progfile_dir(void)
*
* Otherwise, if the program was executed from the build directory, use the
* directory in which the executable for this process resides. In all other
* cases, use the DATAFILE_DIR value that was set at compile time.
*
* XXX - if we ever make libwireshark a real library, used by multiple
* applications (more than just TShark and versions of Wireshark with
@@ -864,7 +864,7 @@ get_datafile_dir(void)
*/
datafile_dir = g_strdup(progfile_dir);
} else {
- datafile_dir = g_strdup(DATAFILE_DIR);
+ datafile_dir = g_strdup(DATA_DIR);
}
#endif
@@ -771,7 +771,7 @@ get_progfile_dir(void)
* Otherwise, if the program was executed from the build directory, use the
* directory in which the executable for this process resides. In all other
- * cases, use the DATAFILE_DIR value that was set at compile time.
+ * cases, use the DATA_DIR value that was set at compile time.
*
* XXX - if we ever make libwireshark a real library, used by multiple